If you’re using the service, you’re probably looking for KinesisVideoArchivedMediaClient and KinesisVideoArchivedMedia.
Structs
- Clip
Fragment Selector Describes the timestamp range and timestamp origin of a range of fragments.
Fragments that have duplicate producer timestamps are deduplicated. This means that if producers are producing a stream of fragments with producer timestamps that are approximately equal to the true clock time, the clip will contain all of the fragments within the requested timestamp range. If some fragments are ingested within the same time range and very different points in time, only the oldest ingested collection of fragments are returned.
- Clip
Timestamp Range The range of timestamps for which to return fragments.
The values in the ClipTimestampRange are
inclusive. Fragments that begin before the start time but continue past it, or fragments that begin before the end time but continue past it, are included in the session.- DASH
Fragment Selector Contains the range of timestamps for the requested media, and the source of the timestamps.
- DASH
Timestamp Range The start and end of the timestamp range for the requested media.
This value should not be present if
PlaybackTypeisLIVE.The values in the
DASHimestampRangeare inclusive. Fragments that begin before the start time but continue past it, or fragments that begin before the end time but continue past it, are included in the session.- Fragment
Represents a segment of video or other time-delimited data.
- Fragment
Selector Describes the timestamp range and timestamp origin of a range of fragments.
Only fragments with a start timestamp greater than or equal to the given start time and less than or equal to the end time are returned. For example, if a stream contains fragments with the following start timestamps:
-
00:00:00
-
00:00:02
-
00:00:04
-
00:00:06
A fragment selector range with a start time of 00:00:01 and end time of 00:00:04 would return the fragments with start times of 00:00:02 and 00:00:04.
-
- GetClip
Input - GetClip
Output - GetDASH
Streaming SessionURL Input - GetDASH
Streaming SessionURL Output - GetHLS
Streaming SessionURL Input - GetHLS
Streaming SessionURL Output - GetMedia
ForFragment List Input - GetMedia
ForFragment List Output - HLSFragment
Selector Contains the range of timestamps for the requested media, and the source of the timestamps.
- HLSTimestamp
Range The start and end of the timestamp range for the requested media.
This value should not be present if
PlaybackTypeisLIVE.The values in the
HLSTimestampRangeare inclusive. Fragments that begin before the start time but continue past it, or fragments that begin before the end time but continue past it, are included in the session.- Kinesis
Video Archived Media Client - A client for the Kinesis Video Archived Media API.
- List
Fragments Input - List
Fragments Output - Timestamp
Range The range of timestamps for which to return fragments.
Enums
- GetClip
Error - Errors returned by GetClip
- GetDASH
Streaming SessionURL Error - Errors returned by GetDASHStreamingSessionURL
- GetHLS
Streaming SessionURL Error - Errors returned by GetHLSStreamingSessionURL
- GetMedia
ForFragment List Error - Errors returned by GetMediaForFragmentList
- List
Fragments Error - Errors returned by ListFragments
Traits
- Kinesis
Video Archived Media - Trait representing the capabilities of the Kinesis Video Archived Media API. Kinesis Video Archived Media clients implement this trait.